==> fuse-0.6.1.1.tar.gz: fuse-0.6.1.1/debugger/commandy.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LOGICAL_OR = 258,
     LOGICAL_AND = 259,
     COMPARISION = 260,
     EQUALITY = 261,
     NEGATE = 262,
     TIMES_DIVIDE = 263,
     BASE = 264,
     BREAK = 265,
     TBREAK = 266,
     CLEAR = 267,
     CONDITION = 268,
     CONTINUE = 269,
     DELETE = 270,
     DISASSEMBLE = 271,
     FINISH = 272,
     IF = 273,
     IGNORE = 274,
     NEXT = 275,
     DEBUGGER_OUT = 276,
     PORT = 277,
     READ = 278,
     SET = 279,
     STEP = 280,
     WRITE = 281,
     REGISTER = 282,
     NUMBER = 283,
     ERROR = 284
   };
#endif
#define LOGICAL_OR 258
#define LOGICAL_AND 259
#define COMPARISION 260
#define EQUALITY 261
#define NEGATE 262
#define TIMES_DIVIDE 263
#define BASE 264
#define BREAK 265
#define TBREAK 266
#define CLEAR 267
#define CONDITION 268
#define CONTINUE 269
#define DELETE 270
#define DISASSEMBLE 271
#define FINISH 272
#define IF 273
#define IGNORE 274
#define NEXT 275
#define DEBUGGER_OUT 276
#define PORT 277
#define READ 278
#define SET 279
#define STEP 280
#define WRITE 281
#define REGISTER 282
#define NUMBER 283
#define ERROR 284




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 49 "commandy.y"
typedef union YYSTYPE {

  int token;
  int reg;

  libspectrum_word integer;
  debugger_breakpoint_type bptype;
  debugger_breakpoint_life bplife;

  debugger_expression* exp;

} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 108 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> fuse-0.6.2.1.tar.gz: fuse-0.6.2.1/debugger/commandy.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LOGICAL_OR = 258,
     LOGICAL_AND = 259,
     COMPARISION = 260,
     EQUALITY = 261,
     NEGATE = 262,
     TIMES_DIVIDE = 263,
     BASE = 264,
     BREAK = 265,
     TBREAK = 266,
     CLEAR = 267,
     CONDITION = 268,
     CONTINUE = 269,
     DELETE = 270,
     DISASSEMBLE = 271,
     FINISH = 272,
     IF = 273,
     IGNORE = 274,
     NEXT = 275,
     DEBUGGER_OUT = 276,
     PORT = 277,
     READ = 278,
     SET = 279,
     STEP = 280,
     TIME = 281,
     WRITE = 282,
     REGISTER = 283,
     NUMBER = 284,
     ERROR = 285
   };
#endif
#define LOGICAL_OR 258
#define LOGICAL_AND 259
#define COMPARISION 260
#define EQUALITY 261
#define NEGATE 262
#define TIMES_DIVIDE 263
#define BASE 264
#define BREAK 265
#define TBREAK 266
#define CLEAR 267
#define CONDITION 268
#define CONTINUE 269
#define DELETE 270
#define DISASSEMBLE 271
#define FINISH 272
#define IF 273
#define IGNORE 274
#define NEXT 275
#define DEBUGGER_OUT 276
#define PORT 277
#define READ 278
#define SET 279
#define STEP 280
#define TIME 281
#define WRITE 282
#define REGISTER 283
#define NUMBER 284
#define ERROR 285




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 46 "commandy.y"
typedef union YYSTYPE {

  int token;
  int reg;

  libspectrum_dword integer;
  debugger_breakpoint_type bptype;
  debugger_breakpoint_life bplife;
  debugger_breakpoint_value bpvalue;

  debugger_expression* exp;

} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 111 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
